@@ -9,6 +9,7 @@ from __future__ import annotations
 import enum
 import inspect
 import sys
+from collections import defaultdict
 from contextlib import suppress
 from pathlib import Path
 from textwrap import dedent
@@ -19,7 +20,7 @@ from griffe.docstrings.dataclasses import DocstringSection
 from griffe.docstrings.parsers import Parser, parse  # noqa: WPS347
 from griffe.exceptions import AliasResolutionError, BuiltinModuleError, CyclicAliasError, NameResolutionError
 from griffe.expressions import Expression, Name
-from griffe.mixins import GetMembersMixin, ObjectAliasMixin, SetMembersMixin
+from griffe.mixins import GetMembersMixin, ObjectAliasMixin, SerializationMixin, SetMembersMixin
 
 # TODO: remove once Python 3.7 support is dropped
 if sys.version_info < (3, 8):
@@ -54,13 +55,15 @@ class Decorator:
         endlineno: The ending line number.
     """
 
-    def __init__(self, lineno: int | None, endlineno: int | None) -> None:
+    def __init__(self, value: str, *, lineno: int | None, endlineno: int | None) -> None:
         """Initialize the decorator.
 
         Parameters:
+            value: The decorator code.
             lineno: The starting line number.
             endlineno: The ending line number.
         """
+        self.value: str = value
         self.lineno: int | None = lineno
         self.endlineno: int | None = endlineno
 
@@ -74,6 +77,7 @@ class Decorator:
             A dictionary.
         """
         return {
+            "value": self.value,
             "lineno": self.lineno,
             "endlineno": self.endlineno,
         }
@@ -109,7 +113,7 @@ class Docstring:
             parser: The docstring parser to use. By default, no parsing is done.
             parser_options: Additional docstring parsing options.
         """
-        self.value: str = inspect.cleandoc(value)
+        self.value: str = inspect.cleandoc(value.rstrip())
         self.lineno: int | None = lineno
         self.endlineno: int | None = endlineno
         self.parent: Object | None = parent
@@ -247,6 +251,9 @@ class Parameters:
     def __iter__(self):
         return iter(self._parameters_list)
 
+    def __contains__(self, param_name: str):
+        return param_name in self._parameters_dict
+
     def add(self, parameter: Parameter) -> None:
         """Add a parameter to the container.
 
@@ -280,7 +287,7 @@ class Kind(enum.Enum):
     ALIAS: str = "alias"
 
 
-class Object(GetMembersMixin, SetMembersMixin, ObjectAliasMixin):
+class Object(GetMembersMixin, SetMembersMixin, ObjectAliasMixin, SerializationMixin):  # noqa: WPS215
     """An abstract class representing a Python object.
 
     Attributes:
@@ -296,6 +303,7 @@ class Object(GetMembersMixin, SetMembersMixin, ObjectAliasMixin):
 
     kind: Kind
     is_alias: bool = False
+    is_collection = False
 
     def __init__(
         self,
@@ -303,6 +311,7 @@ class Object(GetMembersMixin, SetMembersMixin, ObjectAliasMixin):
         *,
         lineno: int | None = None,
         endlineno: int | None = None,
+        runtime: bool = True,
         docstring: Docstring | None = None,
         parent: Module | Class | None = None,
         lines_collection: LinesCollection | None = None,
@@ -314,6 +323,7 @@ class Object(GetMembersMixin, SetMembersMixin, ObjectAliasMixin):
             name: The object name, as declared in the code.
             lineno: The object starting line, or None for modules. Lines start at 1.
             endlineno: The object ending line (inclusive), or None for modules.
+            runtime: Whether this object is present at runtime or not.
             docstring: The object docstring.
             parent: The object parent.
             lines_collection: A collection of source code lines.
@@ -327,8 +337,9 @@ class Object(GetMembersMixin, SetMembersMixin, ObjectAliasMixin):
         self.members: dict[str, Object | Alias] = {}
         self.labels: set[str] = set()
         self.imports: dict[str, str] = {}
-        self.exports: set[str] | None = None
+        self.exports: set[str] | list[str | Name] | None = None
         self.aliases: dict[str, Alias] = {}
+        self.runtime: bool = runtime
         self._lines_collection: LinesCollection | None = lines_collection
         self._modules_collection: ModulesCollection | None = modules_collection
 
@@ -339,6 +350,9 @@ class Object(GetMembersMixin, SetMembersMixin, ObjectAliasMixin):
     def __repr__(self) -> str:
         return f"<{self.__class__.__name__}({self.name!r}, {self.lineno!r}, {self.endlineno!r})>"
 
+    def __bool__(self) -> bool:
+        return True
+
     def __len__(self) -> int:
         return len(self.members) + sum(len(member) for member in self.members.values())
 
@@ -363,7 +377,8 @@ class Object(GetMembersMixin, SetMembersMixin, ObjectAliasMixin):
         By exported, we mean that the object is included in the `__all__` attribute
         of its parent module or class. When `_all__` is not defined,
         we consider the member to be *implicitely* exported,
-        unless it's a module and it was not imported.
+        unless it's a module and it was not imported,
+        and unless it's not defined at runtime.
 
         Parameters:
             member: The member to verify.
@@ -372,6 +387,8 @@ class Object(GetMembersMixin, SetMembersMixin, ObjectAliasMixin):
         Returns:
             True or False.
         """
+        if not member.runtime:
+            return False
         if self.exports is None:
             return not explicitely and (member.is_alias or not member.is_module or member.name in self.imports)
         return member.name in self.exports
@@ -753,6 +770,7 @@ class Alias(ObjectAliasMixin):
         *,
         lineno: int | None = None,
         endlineno: int | None = None,
+        runtime: bool = True,
         parent: Module | Class | None = None,
     ) -> None:
         """Initialize the alias.
@@ -763,6 +781,7 @@ class Alias(ObjectAliasMixin):
                 If it's an object, or even another alias, the target is immediately set.
             lineno: The alias starting line number.
             endlineno: The alias ending line number.
+            runtime: Whether this alias is present at runtime or not.
             parent: The alias parent.
         """
         self.name: str = name
@@ -777,6 +796,7 @@ class Alias(ObjectAliasMixin):
                     target.aliases[self.path] = self
         self.alias_lineno: int | None = lineno
         self.alias_endlineno: int | None = endlineno
+        self.runtime: bool = runtime
         self._parent: Module | Class | None = parent
         self._passed_through: bool = False
 
@@ -993,6 +1013,7 @@ class Module(Object):
         """
         super().__init__(*args, **kwargs)
         self._filepath: Path | list[Path] | None = filepath
+        self.overloads: dict[str, list[Function]] = defaultdict(list)
 
     def __repr__(self) -> str:
         try:
@@ -1113,6 +1134,26 @@ class Class(Object):
         super().__init__(*args, **kwargs)
         self.bases: list[Name | Expression | str] = bases or []
         self.decorators: list[Decorator] = decorators or []
+        self.overloads: dict[str, list[Function]] = defaultdict(list)
+
+    @property
+    def parameters(self) -> Parameters:
+        """Return the parameters of this class' `__init__` method, if any.
+
+        Returns:
+            The parameters containter.
+        """
+        try:
+            return self.members["__init__"].parameters  # type: ignore[union-attr]
+        except KeyError:
+            if "dataclass" in self.labels:
+                return Parameters(
+                    *[
+                        Parameter(attr.name, annotation=attr.annotation, default=attr.value)
+                        for attr in self.attributes.values()
+                    ]
+                )
+            return Parameters()
 
     def as_dict(self, **kwargs: Any) -> dict[str, Any]:  # type: ignore[override]
         """Return this class' data as a dictionary.
@@ -1155,6 +1196,9 @@ class Function(Object):
         self.parameters: Parameters = parameters or Parameters()
         self.returns: str | Name | Expression | None = returns
         self.decorators: list[Decorator] = decorators or []
+        self.setter: Function | None = None
+        self.deleter: Function | None = None
+        self.overloads: list[Function] | None = None
 
     @property
     def annotation(self) -> str | Name | Expression | None:
