@@ -25,8 +25,10 @@ from griffe.collections import LinesCollection, ModulesCollection
 from griffe.dataclasses import Alias, Kind, Module, Object
 from griffe.docstrings.parsers import Parser
 from griffe.exceptions import AliasResolutionError, CyclicAliasError, LoadingError, UnimportableModuleError
-from griffe.finder import ModuleFinder
+from griffe.expressions import Name
+from griffe.finder import ModuleFinder, NamespacePackage, Package
 from griffe.logger import get_logger
+from griffe.merger import merge_stubs
 from griffe.stats import stats
 
 logger = get_logger(__name__)
@@ -49,7 +51,7 @@ def _get_async_reader():
         logger.warning("aiofiles is not installed, fallback to blocking read")
 
         async def _read_async(path):  # noqa: WPS430
-            return path.read_text()
+            return path.read_text(encoding="utf8")
 
     else:
 
@@ -76,6 +78,7 @@ class GriffeLoader:
         docstring_options: dict[str, Any] | None = None,
         lines_collection: LinesCollection | None = None,
         modules_collection: ModulesCollection | None = None,
+        allow_inspection: bool = True,
     ) -> None:
         """Initialize the loader.
 
@@ -86,12 +89,14 @@ class GriffeLoader:
             docstring_options: Additional docstring parsing options.
             lines_collection: A collection of source code lines.
             modules_collection: A collection of modules.
+            allow_inspection: Whether to allow inspecting modules when visiting them is not possible.
         """
         self.extensions: Extensions = extensions or Extensions()
         self.docstring_parser: Parser | None = docstring_parser
         self.docstring_options: dict[str, Any] = docstring_options or {}
         self.lines_collection: LinesCollection = lines_collection or LinesCollection()
         self.modules_collection: ModulesCollection = modules_collection or ModulesCollection()
+        self.allow_inspection: bool = allow_inspection
         self.finder: ModuleFinder = ModuleFinder(search_paths)
         self._time_stats: dict = {
             "time_spent_visiting": 0,
@@ -99,7 +104,7 @@ class GriffeLoader:
         }
         patch_ast()
 
-    def load_module(
+    def load_module(  # noqa: WPS231
         self,
         module: str | Path,
         submodules: bool = True,
@@ -114,27 +119,34 @@ class GriffeLoader:
 
         Raises:
             LoadingError: When loading a module failed for various reasons.
+            ModuleNotFoundError: When a module was not found and inspection is disallowed.
 
         Returns:
             A module.
         """
         module_name: str
         if module in _builtin_modules:
-            logger.debug(f"{module} is a builtin module: inspecting")
-            module_name = module  # type: ignore[assignment]
-            top_module = self._inspect_module(module)  # type: ignore[arg-type]
-            return self._store_and_return(module_name, top_module)
-
-        try:
+            logger.debug(f"{module} is a builtin module")
+            if self.allow_inspection:
+                logger.debug(f"Inspecting {module}")
+                module_name = module  # type: ignore[assignment]
+                top_module = self._inspect_module(module)  # type: ignore[arg-type]
+                return self._store_and_return(module_name, top_module)
+            raise LoadingError("Cannot load builtin module without inspection")
+        try:  # noqa: WPS503
             module_name, package = self.finder.find_spec(module, try_relative_path)
         except ModuleNotFoundError:
-            logger.debug(f"Could not find {module}: trying inspection")
-            module_name = module  # type: ignore[assignment]
-            top_module = self._inspect_module(module)  # type: ignore[arg-type]
+            logger.debug(f"Could not find {module}")
+            if self.allow_inspection:
+                logger.debug(f"Trying inspection on {module}")
+                module_name = module  # type: ignore[assignment]
+                top_module = self._inspect_module(module)  # type: ignore[arg-type]
+            else:
+                raise
         else:
             logger.debug(f"Found {module}: loading")
             try:  # noqa: WPS505
-                top_module = self._load_module(package.name, package.path, submodules=submodules)
+                top_module = self._load_package(package, submodules=submodules)
             except LoadingError as error:  # noqa: WPS440
                 logger.error(str(error))
                 raise
@@ -162,8 +174,10 @@ class GriffeLoader:
         unresolved: set[str] = set("0")  # init to enter loop
         iteration = 0
         collection = self.modules_collection.members
-        for w_module in list(collection.values()):
-            self.expand_wildcards(w_module)
+        for exports_module in list(collection.values()):
+            self.expand_exports(exports_module)
+        for wildcards_module in list(collection.values()):
+            self.expand_wildcards(wildcards_module)
         while unresolved and unresolved != prev_unresolved and iteration < max_iterations:  # type: ignore[operator]
             prev_unresolved = unresolved - {"0"}
             unresolved = set()
@@ -179,6 +193,25 @@ class GriffeLoader:
             )
         return unresolved, iteration
 
+    def expand_exports(self, module: Module) -> None:
+        """Expand exports: try to recursively expand all module exports.
+
+        Parameters:
+            module: The module to recurse on.
+        """
+        if module.exports is None:
+            return
+        expanded = set()
+        for export in module.exports:
+            if isinstance(export, Name):
+                module_path = export.full.rsplit(".", 1)[0]  # remove trailing .__all__
+                next_module = self.modules_collection[module_path]
+                self.expand_exports(next_module)
+                expanded |= next_module.exports
+            else:
+                expanded.add(export)
+        module.exports = expanded
+
     def expand_wildcards(  # noqa: WPS231
         self,
         obj: Object,
@@ -225,7 +258,13 @@ class GriffeLoader:
             del obj[name]  # noqa: WPS420
 
         for new_member, alias_lineno, alias_endlineno in expanded:
-            if new_member.name not in obj.members or obj[new_member.name].lineno < alias_lineno:
+            overwrite = False
+            already_present = new_member.name in obj.members
+            if already_present:
+                old_member = obj[new_member.name]
+                old_lineno = getattr(old_member, "alias_lineno", old_member.lineno or 0)
+                overwrite = alias_lineno > old_lineno  # type: ignore[operator]
+            if not already_present or overwrite:
                 obj[new_member.name] = Alias(
                     new_member.name, new_member, lineno=alias_lineno, endlineno=alias_endlineno
                 )
@@ -303,6 +342,15 @@ class GriffeLoader:
         self.modules_collection[module.path] = module
         return self.modules_collection[name]  # type: ignore[index]
 
+    def _load_package(self, package: Package | NamespacePackage, submodules: bool = True) -> Module:
+        top_module = self._load_module(package.name, package.path, submodules=submodules)
+        if isinstance(package, NamespacePackage):
+            return top_module
+        if package.stubs:
+            stubs = self._load_module(package.name, package.stubs, submodules=False)
+            return merge_stubs(top_module, stubs)
+        return top_module
+
     def _load_module(  # noqa: WPS238
         self,
         module_name: str,
@@ -331,11 +379,13 @@ class GriffeLoader:
         logger.debug(f"Loading path {module_path}")
         if isinstance(module_path, list):
             module = self._create_module(module_name, module_path)
-        elif module_path.suffix == ".py":
+        elif module_path.suffix in {".py", ".pyi"}:
             code = module_path.read_text(encoding="utf8")
             module = self._visit_module(code, module_name, module_path, parent)
-        else:
+        elif self.allow_inspection:
             module = self._inspect_module(module_name, module_path, parent)
+        else:
+            raise LoadingError("Cannot load compiled module without inspection")
         if submodules:
             self._load_submodules(module)
         return module
@@ -433,3 +483,66 @@ class GriffeLoader:
             for imported_member in module.members.values()
             if imported_member.is_exported(explicitely=explicitely)
         ]
+
+
+def load(
+    module: str | Path,
+    submodules: bool = True,
+    try_relative_path: bool = True,
+    extensions: Extensions | None = None,
+    search_paths: Sequence[str | Path] | None = None,
+    docstring_parser: Parser | None = None,
+    docstring_options: dict[str, Any] | None = None,
+    lines_collection: LinesCollection | None = None,
+    modules_collection: ModulesCollection | None = None,
+    allow_inspection: bool = True,
+) -> Module:
+    """Load and return a module.
+
+    Example:
+
+    ```python
+    import griffe
+
+    module = griffe.load(...)
+    ```
+
+    This is a shortcut for:
+
+    ```python
+    from griffe.loader import GriffeLoader
+
+    loader = GriffeLoader(...)
+    module = loader.load_module(...)
+    ```
+
+    See the documentation for the loader: [`GriffeLoader`][griffe.loader.GriffeLoader].
+
+    Parameters:
+        module: The module name or path.
+        submodules: Whether to recurse on the submodules.
+        try_relative_path: Whether to try finding the module as a relative path.
+        extensions: The extensions to use.
+        search_paths: The paths to search into.
+        docstring_parser: The docstring parser to use. By default, no parsing is done.
+        docstring_options: Additional docstring parsing options.
+        lines_collection: A collection of source code lines.
+        modules_collection: A collection of modules.
+        allow_inspection: Whether to allow inspecting modules when visiting them is not possible.
+
+    Returns:
+        A loaded module.
+    """
+    return GriffeLoader(
+        extensions=extensions,
+        search_paths=search_paths,
+        docstring_parser=docstring_parser,
+        docstring_options=docstring_options,
+        lines_collection=lines_collection,
+        modules_collection=modules_collection,
+        allow_inspection=allow_inspection,
+    ).load_module(
+        module=module,
+        submodules=submodules,
+        try_relative_path=try_relative_path,
+    )
